@@ -103,6 +103,7 @@ RDO_PKG_MAP = [
     SingleRule('tripleo-incubator', 'openstack-tripleo'),
     SingleRule('python-pika-pool', 'python-pika_pool'),
     SingleRule('suds-jurko', 'python-suds'),
+    SingleRule('wsgi_intercept', 'python-wsgi_intercept'),
     MultiRule(
         mods=['PyYAML', 'm2crypto', 'numpy', 'pyflakes', 'pylint', 'pyparsing',
               'pytz', 'pysendfile', 'libvirt-python'],
@@ -135,12 +136,12 @@ SUSE_PKG_MAP = [
     # OpenStack clients
     MultiRule(
         mods=['python-%sclient' % c for c in (
-                  'k8s', 'aodh', 'barbican', 'ceilometer', 'congress',
-                  'designate', 'heat', 'glance', 'ironic', 'keystone',
-                  'magnum', 'manila', 'mistral', 'murano', 'monasca',
-                  'neutron', 'nova', 'openstack', 'sahara', 'searchlight',
-                  'senlin', 'smaug', 'solum', 'swift', 'tacker', 'trove',
-                  'watcher', 'zaqar')],
+            'k8s', 'aodh', 'barbican', 'ceilometer', 'congress',
+            'designate', 'fuel', 'heat', 'glance', 'gnocchi', 'ironic',
+            'keystone', 'magnum', 'manila', 'mistral', 'murano', 'monasca',
+            'neutron', 'nova', 'openstack', 'sahara', 'searchlight',
+            'senlin', 'smaug', 'solum', 'swift', 'tacker', 'tripleo', 'trove',
+            'watcher', 'zaqar')],
         pkgfun=lambda x: x),
 ]
 
